@@ -2,7 +2,7 @@
 
 =head1 LICENSE
 
-Copyright (c) 2016-2019 G.W. Haywood.  All rights reserved.
+Copyright (c) 2016-2022 G.W. Haywood.  All rights reserved.
   With thanks to all those who have trodden these paths before,
   including
 Copyright (c) 2002-2004 Todd Vierling.  All rights reserved.
@@ -50,9 +50,9 @@ use Carp;
 use Socket;
 use UNIVERSAL;
 
-use Sendmail::PMilter 1.20_01 qw(:all);
+use Sendmail::PMilter 1.21 qw(:all);
 
-our $VERSION = '1.20_03';
+our $VERSION = '1.21';
 $VERSION = eval $VERSION;
 
 =pod
